@@ -1,3 +1,4 @@
+from bergen.auths.code.app import AuthorizationCodeApplication
 from pydantic.main import BaseModel
 from bergen.auths.legacy.app import LegacyApplication
 from bergen.auths.backend.app import ArnheimBackendOauth
@@ -68,6 +69,7 @@ class Bergen(BaseBergen):
 
 
         if herre_config.authorization_grant_type == GrantType.CLIENT_CREDENTIALS: auth = ArnheimBackendOauth(herre_config, force_new_token=force_new_token)
+        elif herre_config.authorization_grant_type == GrantType.AUHORIZATION_CODE: auth = AuthorizationCodeApplication(herre_config, force_new_token=force_new_token)
         elif herre_config.authorization_grant_type == GrantType.IMPLICIT: auth = ImplicitApplication(herre_config, force_new_token=force_new_token)
         elif herre_config.authorization_grant_type == GrantType.PASSWORD: auth = LegacyApplication(herre_config, username=username, password=password, force_new_token=force_new_token)
         else: raise NotImplementedError("Please Specifiy a valid Grant Type")
