@@ -1,6 +1,6 @@
 from bergen.messages import *
 
-def build_assign_message(reference, reservation, args, kwargs, with_progress=False, context=None, persist=False):
+def build_assign_message(reference, reservation, args, kwargs, with_log=False, context=None, persist=False):
     assert reference is not None, "Must have a reference"
 
     data = {
@@ -12,7 +12,7 @@ def build_assign_message(reference, reservation, args, kwargs, with_progress=Fal
     meta = {
                                     "reference": reference, 
                                     "extensions": {
-                                        "with_progress": with_progress,
+                                        "with_progress": with_log,
                                         "persist": persist
                                     }
     }
@@ -26,7 +26,7 @@ def build_assign_message(reference, reservation, args, kwargs, with_progress=Fal
 
 
 
-def build_unassign_messsage(reference, assignation, with_progress=False, context=None, persist=False):
+def build_unassign_messsage(reference, assignation, with_log=False, context=None, persist=False):
     assert reference is not None, "Must have a reference"
     data= {
                                         "assignation": assignation
@@ -35,7 +35,7 @@ def build_unassign_messsage(reference, assignation, with_progress=False, context
     meta={
                                     "reference": reference, 
                                     "extensions": {
-                                        "with_progress": with_progress,
+                                        "with_progress": with_log,
                                         "persist": persist
                                     }
     }
@@ -48,7 +48,7 @@ def build_unassign_messsage(reference, assignation, with_progress=False, context
         return UnassignMessage(data=data, meta=meta)
 
 
-def build_reserve_message(reference, node_id: str, template_id: str, provision: str, params_dict: dict = {}, with_progress=False, context=None):
+def build_reserve_message(reference, node_id: str, template_id: str, provision: str, params_dict: dict = {}, with_log=False, context=None):
     assert reference is not None, "Must have a reference"
     assert node_id is not None or template_id is not None, "Please provide either a node_id or template_id"
 
@@ -61,7 +61,7 @@ def build_reserve_message(reference, node_id: str, template_id: str, provision:
     meta={
         "reference": reference,
         "extensions": {
-            "with_progress": with_progress,
+            "with_progress": with_log,
         }
     }
 
@@ -74,7 +74,7 @@ def build_reserve_message(reference, node_id: str, template_id: str, provision:
 
 
 
-def build_unreserve_messsage(reference, reservation, with_progress=False, context=None):
+def build_unreserve_messsage(reference, reservation, with_log=False, context=None):
     assert reference is not None, "Must have a reference"
     data= {
                                         "reservation": reservation
@@ -83,7 +83,7 @@ def build_unreserve_messsage(reference, reservation, with_progress=False, contex
     meta={
                                     "reference": reference, 
                                     "extensions": {
-                                        "with_progress": with_progress
+                                        "with_progress": with_log
                                     }
     }
 
